# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.component
from ...awt.x_tab_controller_model import XTabControllerModel as XTabControllerModel_fbef0dd8
from ..form_component import FormComponent as FormComponent_bc700c03
from ..form_components import FormComponents as FormComponents_c8e60c76
from ..x_form import XForm as XForm_684408a8

class Form(FormComponent_bc700c03, FormComponents_c8e60c76, XTabControllerModel_fbef0dd8, XForm_684408a8):
    """
    Service Class

    This service specifies a form which is a group of FormComponents.
    
    A form fulfills several tasks, like storing the structure of its form components, storing the information concerning tab ordering and control grouping, and last but not least, it provides the event environment for its contained elements.
    
    A form acts on the one hand like a container of FormComponents and on the other hand like a FormComponent. This generic construction allows the definition of hierarchies of forms and their dependent subforms.

    See Also:
        `API Form <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1Form.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .table_operation_mode import TableOperationMode as TableOperationMode_b970e3f
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XMultipleOperation(XInterface_8f010a43):
    """
    provides a method to apply a Multiple Operations Table to the cell range.

    See Also:
        `API XMultipleOperation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XMultipleOperation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XMultipleOperation']

    def setTableOperation(self, aFormulaRange: 'CellRangeAddress_ec450d43', nMode: 'TableOperationMode_b970e3f', aColumnCell: 'CellAddress_ae5f0b56', aRowCell: 'CellAddress_ae5f0b56') -> None:
        """
        creates a table of formulas (a \"Multiple Operations Table\").
        
        The specified formulas are repeated, with references to the specified cells replaced by references to values in the first column and/or row of the range.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..container.x_named import XNamed as XNamed_a6520b08
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from .x_sheet_filter_descriptor import XSheetFilterDescriptor as XSheetFilterDescriptor_47cc0ff7
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XDataPilotDescriptor(XNamed_a6520b08):
    """
    provides access to the layout settings of a data pilot table.
    
    This interface extends the interface com.sun.star.container.XNamed which provides access to the name of the data pilot table used e.g. in collections.

    See Also:
        `API XDataPilotDescriptor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XDataPilotDescriptor.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XDataPilotDescriptor']

    def getColumnFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of the data pilot fields used as column fields.
        """
    def getDataFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of the data pilot fields used as data fields.
        """
    def getDataPilotFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of all the data pilot fields.
        """
    def getFilterDescriptor(self) -> 'XSheetFilterDescriptor_47cc0ff7':
        """
        returns the filter descriptor specifying which data from the source cell range are used for the data pilot table.
        """
    def getHiddenFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of the data pilot fields not used as column, row, page, or data fields.
        """
    def getPageFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of the data pilot fields used as page fields.
        """
    def getRowFields(self) -> 'XIndexAccess_f0910d6d':
        """
        returns the collection of the data pilot fields used as row fields.
        """
    def getSourceRange(self) -> 'CellRangeAddress_ec450d43':
        """
        returns the cell range containing the data for the data pilot table.
        """
    def getTag(self) -> str:
        """
        returns an additional string stored in the data pilot table.
        """
    def setSourceRange(self, aSourceRange: 'CellRangeAddress_ec450d43') -> None:
        """
        sets the cell range containing the data for the data pilot table.
        """
    def setTag(self, aTag: str) -> None:
        """
        sets an additional string stored in the data pilot table.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from .x_report_control_model import XReportControlModel as XReportControlModel_2d800f4a
if typing.TYPE_CHECKING:
    from ..drawing.line_dash import LineDash as LineDash_a54e0afc
    from ..drawing.line_style import LineStyle as LineStyle_b1600b8d
    from ..util.color import Color as Color_68e908c5

class XFixedLine(XReportControlModel_2d800f4a):
    """

    See Also:
        `API XFixedLine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFixedLine.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XFixedLine']

    @property
    def LineColor(self) -> 'Color_68e908c5':
        """
        This property contains the line color.
        """

    @property
    def LineDash(self) -> 'LineDash_a54e0afc':
        """
        This property contains the dash of the line.
        """

    @property
    def LineStyle(self) -> 'LineStyle_b1600b8d':
        """
        This property contains the type of the line.
        """

    @property
    def LineTransparence(self) -> int:
        """
        This property contains the extent of transparency.
        """

    @property
    def LineWidth(self) -> int:
        """
        This property contains the width of the line in 1/100th mm.
        """

    @property
    def Orientation(self) -> int:
        """
        specifies the orientation of the control.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
"""
Const

Specifies how to calculate a value.

See Also:
    `API Calculation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1report_1_1Calculation.html>`_
"""
NONE: Literal[0]
"""
returns the average of a field.
"""
AVERAGE: Literal[1]
"""
returns the average of a field.
"""
CORRELATION: Literal[2]
"""
returns the correlation of two fields.
"""
COUNT: Literal[3]
"""
counts the number of values, from the field.
"""
COVARIANCE: Literal[4]
"""
returns the measure of the linear relation between paired variables.
"""
DISTINCTCOUNT: Literal[5]
"""
returns the number of none repeating values, from the field.
"""
MAXIMUM: Literal[6]
"""
returns the largest value from the field.
"""
MEDIAN: Literal[7]
"""
returns the middle value in a sequence of numeric values.
"""
MINIMUM: Literal[8]
"""
returns the smallest value from the field.
"""
MODE: Literal[9]
"""
returns the most frequently returning value from the field.
"""
NTHLARGEST: Literal[10]
"""
returns the Nth largest value from the field.
"""
NTHMOSTFREQUENT: Literal[11]
"""
returns the Nth most commonly occurring value from the field.
"""
NTHSMALLEST: Literal[12]
"""
returns the Nth smallest value from the field.
"""
PERCENTAGE: Literal[13]
"""
returns as a percentage of the grand total summary.
"""
PERCENTILE: Literal[14]
"""
returns the value for a specified percentile in a Number or Currency field.
"""
POPSTANDARDDEVIATION: Literal[15]
"""
returns how much each value in the field deviate from the mean or average value for that field.
"""
POPVARIANCE: Literal[16]
"""
returns the square of the standard deviation.
"""
SAMPLESTANDARDDEVIATION: Literal[17]
"""
returns the sample standard deviation for the field.
"""
SAMPLEVARIANCE: Literal[18]
"""
returns the sample variance for the field.
"""
SUM: Literal[19]
"""
returns the total of all the values for the field.
"""
WEIGHTEDAVG: Literal[20]
"""
returns the weighted average for the field.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.logging
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..util.date_time import DateTime as DateTime_84de09d3


class LogRecord(object):
    """
    Struct Class

    assembles the complete information about a to-be-logged event
    
    **since**
    
        OOo 2.3

    See Also:
        `API LogRecord <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1logging_1_1LogRecord.html>`_
    """
    typeName: Literal['com.sun.star.logging.LogRecord']

    def __init__(self, LoggerName: typing.Optional[str] = ..., SourceClassName: typing.Optional[str] = ..., SourceMethodName: typing.Optional[str] = ..., Message: typing.Optional[str] = ..., LogTime: typing.Optional[DateTime_84de09d3] = ..., SequenceNumber: typing.Optional[int] = ..., ThreadID: typing.Optional[str] = ..., Level: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            LoggerName (str, optional): LoggerName value.
            SourceClassName (str, optional): SourceClassName value.
            SourceMethodName (str, optional): SourceMethodName value.
            Message (str, optional): Message value.
            LogTime (DateTime, optional): LogTime value.
            SequenceNumber (int, optional): SequenceNumber value.
            ThreadID (str, optional): ThreadID value.
            Level (int, optional): Level value.
        """


    @property
    def LoggerName(self) -> str:
        """
        specifies the name of the logger at which the record is logged
        """


    @property
    def SourceClassName(self) -> str:
        """
        specifies the name of the class, in which the record was logged.
        
        This name might be empty, in case the caller to one of the various log methods of XLogger did not specify it.
        """


    @property
    def SourceMethodName(self) -> str:
        """
        specifies the name of the method, in which the record was logged.
        
        This name might be empty, in case the caller to one of the various log methods of XLogger did not specify it.
        """


    @property
    def Message(self) -> str:
        """
        specifies the to-be-logged message
        """


    @property
    def LogTime(self) -> DateTime_84de09d3:
        """
        specifies the time at which the event was logged
        """


    @property
    def SequenceNumber(self) -> int:
        """
        specifies the number of the log event.
        
        Subsequent events get assigned increasing sequence numbers by the XLogger at which they're logged.
        """


    @property
    def ThreadID(self) -> str:
        """
        specifies the ID of the thread in which the event was logged
        """


    @property
    def Level(self) -> int:
        """
        specifies the level of the log event
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from ..lang.x_single_component_factory import XSingleComponentFactory as XSingleComponentFactory_46cc0fef

class WindowContentFactory(XSingleComponentFactory_46cc0fef):
    """
    Service Class

    specifies a factory which creates a window that is a container for user interface elements.
    
    Dependent on the provided arguments different window types can be created. This container window must be capable of being integrated into another window (e.g. docking or floating windows).
    
    The specific type of the created window depends on the provided arguments.
    
    **since**
    
        OOo 3.1

    See Also:
        `API WindowContentFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1WindowContentFactory.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API TextureProjectionMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acb>`_
"""

OBJECTSPECIFIC: 'uno.Enum'
"""
This value specifies that the standard object projection method is used.
"""
PARALLEL: 'uno.Enum'
"""
the 3D objects are drawn in the parallel projection.

This value specifies a flat parallel projection in the specified degree of freedom (X or Y).
"""
SPHERE: 'uno.Enum'
"""
forces normals to think that the object is a sphere.

This value forces projection to wrapping in X and/or Y.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.3
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6


class theUICommandDescription(XNameAccess_e2ab0cf6):
    """
    Singleton Class

    a singleton which provides information about user interface commands of modules.
    
    OpenOffice.org has an amount of commands that can be used by user interface elements. This singleton provides access to the user interface commands that are part of OpenOffice.org modules, like Writer or Calc.
    
    Provides access to user interface commands of the installed modules.
    
    To access the user interface command description of a module, a unique module specifier must be provided to com.sun.star.container.XNameAccess.getByName() function. The module specifier can be retrieved from the com.sun.star.frame.ModuleManager service. The interface provides references to com.sun:star.ui.ModuleUICommandDescription.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) UICommandDescription service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theUICommandDescription <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1frame_1_1theUICommandDescription.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
from enum import Enum

class IOErrorCode(Enum):
    """
    Enum

    

    See Also:
        `API IOErrorCode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5>`_
    """

    ABORT: 'uno.Enum'
    """
    An operation was aborted.
    """
    ACCESS_DENIED: 'uno.Enum'
    """
    An object cannot be accessed due to insufficient user rights.
    """
    ALREADY_EXISTING: 'uno.Enum'
    """
    An object already exists.
    """
    BAD_CRC: 'uno.Enum'
    """
    A bad checksum.
    """
    CANT_CREATE: 'uno.Enum'
    """
    An object could not be created.
    """
    CANT_READ: 'uno.Enum'
    """
    Data could not be read from a file.
    """
    CANT_SEEK: 'uno.Enum'
    """
    A seek operation could not be run.
    """
    CANT_TELL: 'uno.Enum'
    """
    A tell operation could not be run.
    """
    CANT_WRITE: 'uno.Enum'
    """
    Data could not be written to a file.
    """
    CURRENT_DIRECTORY: 'uno.Enum'
    """
    A function is not possible because the path contains the current directory.
    """
    DEVICE_NOT_READY: 'uno.Enum'
    """
    A device (drive) not ready.
    """
    DIFFERENT_DEVICES: 'uno.Enum'
    """
    A function is not possible because the devices (drives) are not identical.
    """
    GENERAL: 'uno.Enum'
    """
    A general input/output error.
    """
    INVALID_ACCESS: 'uno.Enum'
    """
    An invalid attempt was made to access an object.
    """
    INVALID_CHARACTER: 'uno.Enum'
    """
    A file name contains invalid characters.
    """
    INVALID_DEVICE: 'uno.Enum'
    """
    A specified device is invalid.
    """
    INVALID_LENGTH: 'uno.Enum'
    """
    Invalid data length.
    """
    INVALID_PARAMETER: 'uno.Enum'
    """
    An operation was started with an invalid parameter.
    """
    IS_WILDCARD: 'uno.Enum'
    """
    An operation cannot be run on file names containing wildcards.
    """
    LOCKING_VIOLATION: 'uno.Enum'
    """
    A locking problem.
    """
    MISPLACED_CHARACTER: 'uno.Enum'
    """
    An invalid file name.
    """
    NAME_TOO_LONG: 'uno.Enum'
    """
    A file name is too long.
    """
    NOT_EXISTING: 'uno.Enum'
    """
    A nonexistent object.
    """
    NOT_EXISTING_PATH: 'uno.Enum'
    """
    The path to a file does not exist.
    """
    NOT_SUPPORTED: 'uno.Enum'
    """
    An action is not supported.
    """
    NO_DIRECTORY: 'uno.Enum'
    """
    An object is not a directory.
    """
    NO_FILE: 'uno.Enum'
    """
    An object is not a file.
    """
    OUT_OF_DISK_SPACE: 'uno.Enum'
    """
    No more space on a device.
    """
    OUT_OF_FILE_HANDLES: 'uno.Enum'
    """
    No more file handles available.
    """
    OUT_OF_MEMORY: 'uno.Enum'
    """
    An operation could not be run due to insufficient memory.
    """
    PENDING: 'uno.Enum'
    """
    An operation is still pending.
    """
    RECURSIVE: 'uno.Enum'
    """
    An object cannot be copied into itself.
    """
    UNKNOWN: 'uno.Enum'
    """
    Unknown.
    
    An unknown I/O error has occurred.
    """
    WRITE_PROTECTED: 'uno.Enum'
    """
    A function is not possible because the object is write protected.
    """
    WRONG_FORMAT: 'uno.Enum'
    """
    An incorrect file format.
    """
    WRONG_VERSION: 'uno.Enum'
    """
    An incorrect file version.
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration.backend
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .template_identifier import TemplateIdentifier as TemplateIdentifier_2aaa14b5

class XLayerHandler(XInterface_8f010a43):
    """
    receives a description of a configuration layer as a sequence of events.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XLayerHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XLayerHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.configuration.backend.XLayerHandler']

    def addOrReplaceNode(self, aName: str, aAttributes: int) -> None:
        """
        receives notification that a new item is started.
        
        The current node must be a set and a preexisting item (if any) must be removable.
        
        The new item will be created from the default template of the set.
        
        Subsequent calls describe the difference from the template of properties and members or items of the node until a matching call to XLayerHandler.endNode() is encountered.
        
        The value is a combination of NodeAttribute flags. Note that NodeAttribute.FUSE has an impact on the semantics of this method.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addOrReplaceNodeFromTemplate(self, aName: str, aTemplate: 'TemplateIdentifier_2aaa14b5', aAttributes: int) -> None:
        """
        receives notification that a new item based on a particular template is started.
        
        The current node must be a set and a preexisting item (if any) must be removable.
        
        Subsequent calls describe the difference from the template of properties and members or items of the node until a matching call to XLayerHandler.endNode() is encountered.
        
        The value is a combination of NodeAttribute flags. Note that NodeAttribute.FUSE has an impact on the semantics of this method.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addProperty(self, aName: str, aAttributes: int, aType: object) -> None:
        """
        receives notification that a property having a VOID value is added to the current node.
        
        The current node must be extensible.
        
        The value is a combination of NodeAttribute flags and may also contain the SchemaAttribute.REQUIRED flag.
        
        NodeAttribute.MANDATORY need not be set, as dynamically added properties always are mandatory in subsequent layers.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def addPropertyWithValue(self, aName: str, aAttributes: int, aValue: object) -> None:
        """
        receives notification that a property having a non-VOID value is added to the current node.
        
        The current node must be extensible.
        
        The value is a combination of NodeAttribute flags and may also contain the SchemaAttribute.REQUIRED flag.
        
        NodeAttribute.MANDATORY need not be set, as dynamic properties always are mandatory in subsequent layers.
        
        The value also determines the type. Therefore the value must not be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def dropNode(self, aName: str) -> None:
        """
        receives notification that a node is dropped from a set.
        
        The current node must be a set and the item must be removable.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endLayer(self) -> None:
        """
        receives notification that a layer description is complete.
        
        Must match a previous call to XLayerHandler.startLayer().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endNode(self) -> None:
        """
        receives notification that a node description is complete.
        
        Must match the last open call to XLayerHandler.overrideNode(), XLayerHandler.addOrReplaceNode() or XLayerHandler.addOrReplaceNodeFromTemplate().
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def endProperty(self) -> None:
        """
        receives notification that a property description is complete.
        
        Must match an open call to XLayerHandler.overrideProperty(),
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def overrideNode(self, aName: str, aAttributes: int, bClear: bool) -> None:
        """
        receives notification that a description of a node override is started.
        
        Subsequent calls describe overrides to properties and members or items of the node until a matching call to XLayerHandler.endNode()is encountered.
        
        The value is a combination of NodeAttribute flags.
        
        The attributes are combined cumulatively with those set on lower layers.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def overrideProperty(self, aName: str, aAttributes: int, aType: object, bClear: bool) -> None:
        """
        receives notification that an existing property is modified.
        
        Subsequent calls describe new value(s) for the property until a matching call to XLayerHandler.endProperty() is encountered.
        
        The value is a combination of NodeAttribute flags.
        
        The attributes are combined cumulatively with those set on lower layers.
        
        This must be the same type as is already defined in the schema or lower layers, unless the previous type was unspecified (as indicated by com.sun.star.uno.TypeClass.ANY.)
        
        A VOID type indicates that the type is unspecified in this layer. In this case any subsequent value may be of a generic type (e.g. string or - for list values - string[].) Such values may be converted to the type defined in the schema by the implementation.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setPropertyValue(self, aValue: object) -> None:
        """
        receives notification that the value of the current property is overridden.
        
        The value must match the type of the current property. If the property does not have the SchemaAttribute.REQUIRED flag set, the value can be VOID.
        
        If the current property is localized, this value applies to the default locale.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def setPropertyValueForLocale(self, aValue: object, aLocale: str) -> None:
        """
        receives notification that the value of the current localized property is overridden for a specific locale .
        
        The value must match the type of the current property. If the property does not have the SchemaAttribute.REQUIRED flag set, the value can be VOID.
        
        Not every implementation can detect each condition

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def startLayer(self) -> None:
        """
        receives notification that a layer description is started for a component.
        
        Subsequent calls describe the contents of the layer until a matching call to XLayerHandler.endLayer() is encountered.

        Raises:
            MalformedDataException: ``MalformedDataException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from .x_service_type_description import XServiceTypeDescription as XServiceTypeDescription_b4481282
if typing.TYPE_CHECKING:
    from .x_service_constructor_description import XServiceConstructorDescription as XServiceConstructorDescription_430d1586
    from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1

class XServiceTypeDescription2(XServiceTypeDescription_b4481282):
    """
    Reflects a service, supporting single-interface–based services.
    
    This type supersedes XServiceTypeDescription, which only supports obsolete, accumulation-based services.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XServiceTypeDescription2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XServiceTypeDescription2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XServiceTypeDescription2']

    def getConstructors(self) -> 'typing.Tuple[XServiceConstructorDescription_430d1586, ...]':
        """
        Returns the constructors of the service.
        """
    def getInterface(self) -> 'XTypeDescription_3c210fb1':
        """
        Returns the interface type associated with the service.
        """
    def isSingleInterfaceBased(self) -> bool:
        """
        Returns whether this object reflects a single-interface–based service.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class Panose(object):
    """
    Struct Class


    See Also:
        `API Panose <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1Panose.html>`_
    """
    typeName: Literal['com.sun.star.rendering.Panose']

    def __init__(self, FamilyType: typing.Optional[int] = ..., SerifStyle: typing.Optional[int] = ..., Weight: typing.Optional[int] = ..., Proportion: typing.Optional[int] = ..., Contrast: typing.Optional[int] = ..., StrokeVariation: typing.Optional[int] = ..., ArmStyle: typing.Optional[int] = ..., Letterform: typing.Optional[int] = ..., Midline: typing.Optional[int] = ..., XHeight: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            FamilyType (int, optional): FamilyType value.
            SerifStyle (int, optional): SerifStyle value.
            Weight (int, optional): Weight value.
            Proportion (int, optional): Proportion value.
            Contrast (int, optional): Contrast value.
            StrokeVariation (int, optional): StrokeVariation value.
            ArmStyle (int, optional): ArmStyle value.
            Letterform (int, optional): Letterform value.
            Midline (int, optional): Midline value.
            XHeight (int, optional): XHeight value.
        """


    @property
    def FamilyType(self) -> int:
        """
        PanoseFamilyTypes.
        """


    @property
    def SerifStyle(self) -> int:
        """
        PanoseSerifStyle.
        """


    @property
    def Weight(self) -> int:
        """
        PanoseWeight.
        """


    @property
    def Proportion(self) -> int:
        """
        PanoseProportion.
        """


    @property
    def Contrast(self) -> int:
        """
        PanoseContrast.
        """


    @property
    def StrokeVariation(self) -> int:
        """
        PanoseStrokeVariation.
        """


    @property
    def ArmStyle(self) -> int:
        """
        PanoseArmStyle.
        """


    @property
    def Letterform(self) -> int:
        """
        PanoseLetterForm.
        """


    @property
    def Midline(self) -> int:
        """
        PanoseMidline.
        """


    @property
    def XHeight(self) -> int:
        """
        PanoseXHeight.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.drawing
from typing_extensions import Literal


class EnhancedCustomShapeSegmentCommand(object):
    """
    Const


    See Also:
        `API EnhancedCustomShapeSegmentCommand <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegmentCommand.html>`_
    """
    UNKNOWN: Literal[0]
    MOVETO: Literal[1]
    LINETO: Literal[2]
    CURVETO: Literal[3]
    CLOSESUBPATH: Literal[4]
    ENDSUBPATH: Literal[5]
    NOFILL: Literal[6]
    NOSTROKE: Literal[7]
    ANGLEELLIPSETO: Literal[8]
    ANGLEELLIPSE: Literal[9]
    ARCTO: Literal[10]
    ARC: Literal[11]
    CLOCKWISEARCTO: Literal[12]
    CLOCKWISEARC: Literal[13]
    ELLIPTICALQUADRANTX: Literal[14]
    ELLIPTICALQUADRANTY: Literal[15]
    QUADRATICCURVETO: Literal[16]
    ARCANGLETO: Literal[17]
    DARKEN: Literal[18]
    """
    darken fill color
    """
    DARKENLESS: Literal[19]
    """
    darken fill color less
    """
    LIGHTEN: Literal[20]
    """
    lighten fill color
    """
    LIGHTENLESS: Literal[21]
    """
    lighten fill color less
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from .x_status_listener import XStatusListener as XStatusListener_e2740d35
from .x_sub_toolbar_controller import XSubToolbarController as XSubToolbarController_37b30f8c
from .x_toolbar_controller import XToolbarController as XToolbarController_b630e62
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
from ..util.x_updatable import XUpdatable as XUpdatable_9a420ab0

class ToolbarController(XStatusListener_e2740d35, XSubToolbarController_37b30f8c, XToolbarController_b630e62, XInitialization_d46c0cca, XUpdatable_9a420ab0):
    """
    Service Class

    is an abstract service for a component which offers a more complex user interface to users within a toolbar.
    
    A generic toolbar function is represented as a button which has a state (enabled,disabled and selected, not selected). A toolbar controller can be added to a toolbar and provide information or functions within a more sophisticated user interface.
    A typical example for toolbar controller is the font chooser within the toolbar. It provides all available fonts in a dropdown box and shows the current chosen font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ToolbarController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1frame_1_1ToolbarController.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.report
from typing_extensions import Literal
import typing
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from .x_function import XFunction as XFunction_a6b30b42

class XFunctions(XChild_a6390b07, XContainer_d6fb0cc6, XIndexContainer_1c040ebe, XComponent_98dc0ab5):
    """
    This interface specifies the functions collections of the report definition or a group.

    See Also:
        `API XFunctions <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFunctions.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.report.XFunctions']

    def createFunction(self) -> 'XFunction_a6b30b42':
        """
        factory method for XFunction.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class SearchResult(object):
    """
    Struct Class


    See Also:
        `API SearchResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1util_1_1SearchResult.html>`_
    """
    typeName: Literal['com.sun.star.util.SearchResult']

    def __init__(self, startOffset: typing.Optional[typing.Tuple[int, ...]] = ..., endOffset: typing.Optional[typing.Tuple[int, ...]] = ..., subRegExpressions: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            startOffset (typing.Tuple[int, ...], optional): startOffset value.
            endOffset (typing.Tuple[int, ...], optional): endOffset value.
            subRegExpressions (int, optional): subRegExpressions value.
        """


    @property
    def startOffset(self) -> typing.Tuple[int, ...]:
        ...


    @property
    def endOffset(self) -> typing.Tuple[int, ...]:
        ...


    @property
    def subRegExpressions(self) -> int:
        """
        Number of subexpressions.
        
        If it is 0, then no match found; this value is 1 for ABSOLUTE and APPROXIMATE match. The start and endOffset are always dependent on the search direction.
        
        For example, if you search \"X\" in the text \"-X-\" the offsets are:
        
        Forward, the startOffset is inclusive, the endOffset exclusive. Backward, the startOffset is exclusive, the endOffset inclusive.
        
        For regular expressions it can be greater than 1. If the value is 1, startoffset[0] and endoffset[0] points to the matching sub string if value is > 1, still startoffset[0] and endoffset[0] points to the matching substring for whole regular expression startoffset[i] and endoffset[i] points to the matching substring of i th matching substring.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.rdf
from typing_extensions import Literal
import typing
from .x_repository_supplier import XRepositorySupplier as XRepositorySupplier_feff0e30
from .xuri import XURI as XURI_5682078c
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..beans.string_pair import StringPair as StringPair_a4bc0b14
    from ..embed.x_storage import XStorage as XStorage_8e460a32
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from .x_metadatable import XMetadatable as XMetadatable_a3000af0
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XDocumentMetadataAccess(XRepositorySupplier_feff0e30, XURI_5682078c):
    """
    document metadata functionality related to the \"manifest.rdf\".
    
    This interface contains some methods that create connections between the content and the RDF metadata of an ODF document. The main idea is to make querying and manipulating the data in the metadata manifest easier.
    
    Note that this interface inherits from XURI: the base URI of the document is the string value of the RDF node. This is so that you can easily make RDF statements about the document.
    
    **since**
    
        OOo 3.2

    See Also:
        `API XDocumentMetadataAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rdf_1_1XDocumentMetadataAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rdf.XDocumentMetadataAccess']

    def addContentOrStylesFile(self, FileName: str) -> None:
        """
        add a content or styles file to the manifest.
        
        This convenience method adds the required statements declaring a content or styles file to the manifest graph.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def addMetadataFile(self, FileName: str, Types: 'typing.Tuple[XURI_5682078c, ...]') -> 'XURI_5682078c':
        """
        add a metadata file to the manifest.
        
        This convenience method does the following:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
    def getElementByMetadataReference(self, MetadataReference: 'StringPair_a4bc0b14') -> 'XMetadatable_a3000af0':
        """
        get the unique ODF element with the given metadata reference.
        """
    def getElementByURI(self, URI: 'XURI_5682078c') -> 'XMetadatable_a3000af0':
        """
        get the ODF element that corresponds to a URI.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getMetadataGraphsWithType(self, Type: 'XURI_5682078c') -> 'typing.Tuple[XURI_5682078c, ...]':
        """
        get the names of all metadata files with a given type.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def importMetadataFile(self, Format: int, InStream: 'XInputStream_98d40ab4', FileName: str, BaseURI: 'XURI_5682078c', Types: 'typing.Tuple[XURI_5682078c, ...]') -> 'XURI_5682078c':
        """
        import a metadata file into the document repository, and add it to the manifest.
        
        This convenience method does the following:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.datatransfer.UnsupportedFlavorException: ``UnsupportedFlavorException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
            ParseException: ``ParseException``
            com.sun.star.io.IOException: ``IOException``
        """
    def loadMetadataFromMedium(self, Medium: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        loads document metadata from a medium.
        
        If the Medium contains an InteractionHandler, it will be used for error reporting.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def loadMetadataFromStorage(self, Storage: 'XStorage_8e460a32', BaseURI: 'XURI_5682078c', InteractionHandler: 'XInteractionHandler_bf80e51') -> None:
        """
        initialize document metadata from a storage.
        
        This method re-initializes the document metadata, loads the stream named \"manifest.rdf\" from the storage, and then loads all metadata streams mentioned in the manifest.
        
        Note that it is not an error if the storage does not contain a manifest. In this case, the document metadata will be default initialized.
        
        If an InteractionHandler argument is given, it will be used for error reporting. Otherwise, errors will be reported as exceptions.
        
        N.B.: when loading from an ODF package, the base URI is not the URI of the package, but the URI of the directory in the package that contains the metadata.rdf

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def removeContentOrStylesFile(self, FileName: str) -> None:
        """
        remove a content or styles file from the manifest.
        
        This convenience method removes the statements declaring a content or styles file from the manifest graph.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def removeMetadataFile(self, GraphName: 'XURI_5682078c') -> None:
        """
        remove a metadata file from the manifest and the repository.
        
        This convenience method does the following:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
    def storeMetadataToMedium(self, Medium: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        stores document metadata to a medium.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def storeMetadataToStorage(self, Storage: 'XStorage_8e460a32') -> None:
        """
        store document metadata to a storage.
        
        This method stores all the graphs in the document metadata repository to the given storage.
        
        Note that to be stored correctly, a named graph must have a complete entry in the manifest graph.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
"""
Const

provides information about layout manager events

Events are provided only for notification purposes only.

**since**

    OOo 2.0

See Also:
    `API LayoutManagerEvents <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1frame_1_1LayoutManagerEvents.html>`_
"""
LOCK: Literal[0]
"""
specifies that the layout manager processed a lock call, which prevents it from doing layouts.

This event sends the current lock count as additional information.
"""
UNLOCK: Literal[1]
"""
specifies that the layout manager processed an unlock call, which admit layouts when the lock count is zero.

This event sends the current lock count as additional information.
"""
LAYOUT: Literal[2]
"""
specifies that the layout manager refreshed the layout of the frame.

This event sends no additional information.
"""
VISIBLE: Literal[3]
"""
specifies that the layout manager container frame window becomes visible.

This event sends no additional information.
"""
INVISIBLE: Literal[4]
"""
specifies that the layout manager container frame window becomes invisible.

This event sends no additional information.
"""
MERGEDMENUBAR: Literal[5]
"""
A merged menu bar has been set at the layout manager.

This event sends no additional information.
"""
UIELEMENT_VISIBLE: Literal[6]
"""
specifies that a certain user interface element has been made visible

This event sends the resource url of the newly visible user interface element.
"""
UIELEMENT_INVISIBLE: Literal[7]
"""
specifies that a certain user interface element has been made invisible

This event sends the resource url of the invisible user interface element.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sheet
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XPrintAreas(XInterface_8f010a43):
    """
    represents a sheet which has print areas.

    See Also:
        `API XPrintAreas <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XPrintAreas.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sheet.XPrintAreas']

    def getPrintAreas(self) -> 'typing.Tuple[CellRangeAddress_ec450d43, ...]':
        """
        returns a sequence containing all print areas of the sheet.
        """
    def getPrintTitleColumns(self) -> bool:
        """
        returns, whether the title columns are repeated on all subsequent print pages to the right.
        """
    def getPrintTitleRows(self) -> bool:
        """
        returns, whether the title rows are repeated on all subsequent print pages to the bottom.
        """
    def getTitleColumns(self) -> 'CellRangeAddress_ec450d43':
        """
        returns the range that is specified as title columns range.
        
        Title columns can be automatically repeated on all subsequent print pages to the right, using XPrintAreas.setPrintTitleColumns().
        """
    def getTitleRows(self) -> 'CellRangeAddress_ec450d43':
        """
        returns the range that is specified as title rows range.
        
        Title rows can be automatically repeated on all subsequent print pages to the bottom, using XPrintAreas.setPrintTitleRows().
        """
    def setPrintAreas(self, aPrintAreas: 'typing.Tuple[CellRangeAddress_ec450d43, ...]') -> None:
        """
        sets the print areas of the sheet.
        
        If none of the sheets in a document have print areas, the whole sheets are printed. If any sheet contains print areas, other sheets without print areas are not printed.
        """
    def setPrintTitleColumns(self, bPrintTitleColumns: bool) -> None:
        """
        specifies whether the title columns are repeated on all subsequent print pages to the right.
        """
    def setPrintTitleRows(self, bPrintTitleRows: bool) -> None:
        """
        specifies whether the title rows are repeated on all subsequent print pages to the bottom.
        """
    def setTitleColumns(self, aTitleColumns: 'CellRangeAddress_ec450d43') -> None:
        """
        specifies a range of columns as title columns range.
        
        The rows of the passed range are ignored.
        
        Title columns can be automatically repeated on all subsequent print pages to the right, using XPrintAreas.setPrintTitleColumns().
        """
    def setTitleRows(self, aTitleRows: 'CellRangeAddress_ec450d43') -> None:
        """
        specifies a range of rows as title rows range.
        
        The columns of the passed range are ignored.
        
        Title rows can be automatically repeated on all subsequent print pages to the bottom, using XPrintAreas.setPrintTitleRows().
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdbc
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class DriverPropertyInfo(object):
    """
    Struct Class

    describes the driver properties for making a connection.
    
    The DriverPropertyInfo is of interest only to advanced programmers who need to interact with a driver to discover and supply properties for connections.

    See Also:
        `API DriverPropertyInfo <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sdbc_1_1DriverPropertyInfo.html>`_
    """
    typeName: Literal['com.sun.star.sdbc.DriverPropertyInfo']

    def __init__(self, Choices: typing.Optional[typing.Tuple[str, ...]] = ..., Name: typing.Optional[str] = ..., Description: typing.Optional[str] = ..., IsRequired: typing.Optional[bool] = ..., Value: typing.Optional[str] = ...) -> None:
        """
        Constructor

        Arguments:
            Choices (typing.Tuple[str, ...], optional): Choices value.
            Name (str, optional): Name value.
            Description (str, optional): Description value.
            IsRequired (bool, optional): IsRequired value.
            Value (str, optional): Value value.
        """


    @property
    def Choices(self) -> typing.Tuple[str, ...]:
        """
        contains a sequence of possible values if the value for the field DriverPropertyInfo.value may be selected from a particular set of values; otherwise empty.
        """


    @property
    def Name(self) -> str:
        """
        is the name of the property.
        """


    @property
    def Description(self) -> str:
        """
        is a brief description of the property, which may be null.
        """


    @property
    def IsRequired(self) -> bool:
        """
        is TRUE if a value must be supplied for this property during Driver.connect and FALSE otherwise.
        """


    @property
    def Value(self) -> str:
        """
        specifies the current value of the property, based on the driver-supplied default values.
        
        This field may be empty if no value is known.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.3
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API UnicodeScript <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29>`_
"""

kAlphabeticPresentation: 'uno.Enum'
"""
"""
kArabic: 'uno.Enum'
"""
"""
kArabicPresentationA: 'uno.Enum'
"""
"""
kArabicPresentationB: 'uno.Enum'
"""
"""
kArmenian: 'uno.Enum'
"""
"""
kArrow: 'uno.Enum'
"""
"""
kBasicLatin: 'uno.Enum'
"""
"""
kBengali: 'uno.Enum'
"""
"""
kBlockElement: 'uno.Enum'
"""
"""
kBopomofo: 'uno.Enum'
"""
"""
kBopomofoExtended: 'uno.Enum'
"""
"""
kBoxDrawing: 'uno.Enum'
"""
"""
kBraillePatterns: 'uno.Enum'
"""
"""
kCJKCompatibility: 'uno.Enum'
"""
"""
kCJKCompatibilityForm: 'uno.Enum'
"""
"""
kCJKCompatibilityIdeograph: 'uno.Enum'
"""
"""
kCJKRadicalsSupplement: 'uno.Enum'
"""
"""
kCJKSymbolPunctuation: 'uno.Enum'
"""
"""
kCJKUnifiedIdeograph: 'uno.Enum'
"""
"""
kCJKUnifiedIdeographsExtensionA: 'uno.Enum'
"""
"""
kCherokee: 'uno.Enum'
"""
"""
kCombiningDiacritical: 'uno.Enum'
"""
"""
kCombiningHalfMark: 'uno.Enum'
"""
"""
kControlPicture: 'uno.Enum'
"""
"""
kCurrencySymbolScript: 'uno.Enum'
"""
"""
kCyrillic: 'uno.Enum'
"""
"""
kDevanagari: 'uno.Enum'
"""
"""
kDingbat: 'uno.Enum'
"""
"""
kEnclosedAlphanumeric: 'uno.Enum'
"""
"""
kEnclosedCJKLetterMonth: 'uno.Enum'
"""
"""
kEthiopic: 'uno.Enum'
"""
"""
kGeneralPunctuation: 'uno.Enum'
"""
"""
kGeometricShape: 'uno.Enum'
"""
"""
kGeorgian: 'uno.Enum'
"""
"""
kGreek: 'uno.Enum'
"""
"""
kGreekExtended: 'uno.Enum'
"""
"""
kGujarati: 'uno.Enum'
"""
"""
kGurmukhi: 'uno.Enum'
"""
"""
kHalfwidthFullwidthForm: 'uno.Enum'
"""
"""
kHangulCompatibilityJamo: 'uno.Enum'
"""
"""
kHangulJamo: 'uno.Enum'
"""
"""
kHangulSyllable: 'uno.Enum'
"""
"""
kHebrew: 'uno.Enum'
"""
"""
kHighPrivateUseSurrogate: 'uno.Enum'
"""
"""
kHighSurrogate: 'uno.Enum'
"""
"""
kHiragana: 'uno.Enum'
"""
"""
kIPAExtension: 'uno.Enum'
"""
"""
kIdeographicDescriptionCharacters: 'uno.Enum'
"""
"""
kKanbun: 'uno.Enum'
"""
"""
kKangxiRadicals: 'uno.Enum'
"""
"""
kKannada: 'uno.Enum'
"""
"""
kKatakana: 'uno.Enum'
"""
"""
kKhmer: 'uno.Enum'
"""
"""
kLao: 'uno.Enum'
"""
"""
kLatin1Supplement: 'uno.Enum'
"""
"""
kLatinExtendedA: 'uno.Enum'
"""
"""
kLatinExtendedAdditional: 'uno.Enum'
"""
"""
kLatinExtendedB: 'uno.Enum'
"""
"""
kLetterlikeSymbol: 'uno.Enum'
"""
"""
kLowSurrogate: 'uno.Enum'
"""
"""
kMalayalam: 'uno.Enum'
"""
"""
kMathOperator: 'uno.Enum'
"""
"""
kMiscSymbol: 'uno.Enum'
"""
"""
kMiscTechnical: 'uno.Enum'
"""
"""
kMongolian: 'uno.Enum'
"""
"""
kMyanmar: 'uno.Enum'
"""
"""
kNoScript: 'uno.Enum'
"""
"""
kNumberForm: 'uno.Enum'
"""
"""
kOgham: 'uno.Enum'
"""
"""
kOpticalCharacter: 'uno.Enum'
"""
"""
kOriya: 'uno.Enum'
"""
"""
kPrivateUse: 'uno.Enum'
"""
"""
kRunic: 'uno.Enum'
"""
"""
kScriptCount: 'uno.Enum'
"""
"""
kSinhala: 'uno.Enum'
"""
"""
kSmallFormVariant: 'uno.Enum'
"""
"""
kSpacingModifier: 'uno.Enum'
"""
"""
kSuperSubScript: 'uno.Enum'
"""
"""
kSymbolCombiningMark: 'uno.Enum'
"""
"""
kSyriac: 'uno.Enum'
"""
"""
kTamil: 'uno.Enum'
"""
"""
kTelugu: 'uno.Enum'
"""
"""
kThaana: 'uno.Enum'
"""
"""
kThai: 'uno.Enum'
"""
"""
kTibetan: 'uno.Enum'
"""
"""
kUnifiedCanadianAboriginalSyllabics: 'uno.Enum'
"""
"""
kYiRadicals: 'uno.Enum'
"""
"""
kYiSyllables: 'uno.Enum'
"""
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ui
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .xui_element import XUIElement as XUIElement_820509a6

class XUIElementFactory(XInterface_8f010a43):
    """
    specifies a user interface element factory that can create and initialize user interface elements.
    
    User interface element factories must be registered at a UIElementFactoryManager service to provide access to itself.
    
    Currently the following user interface element types are defined:
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIElementFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIElementFactory.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.XUIElementFactory']

    def createUIElement(self, ResourceURL: str, Args: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> 'XUIElement_820509a6':
        """
        creates a new instances of a specific user interface element.
        
        An implementation is responsible to initialize every newly created user interface element if the necessary properties are provided. Especially it must connect a configurable user interface element to the correct user interface configuration manager. Without this connection the configurable user interface element cannot retrieve its structure data and changes to the user interface element structure won't be persistent. It is up to the implementation to throw an com.sun.star.lang.IllegalArgumentException if it cannot create a user interface element with the provided arguments.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.document
from typing_extensions import Literal
from abc import ABC

class XUndoAction(ABC):
    """
    represents a single (undoable) action on a document
    
    **since**
    
        OOo 3.4

    See Also:
        `API XUndoAction <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XUndoAction.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XUndoAction']

    def redo(self) -> None:
        """
        repeats the action represented by the instance, after it had previously been reverted.

        Raises:
            com.sun.star.document.UndoFailedException: ``UndoFailedException``
        """
    def undo(self) -> None:
        """
        reverts the action represented by the instance

        Raises:
            com.sun.star.document.UndoFailedException: ``UndoFailedException``
        """
    @property
    def Title(self) -> str:
        """
        is the human-readable, localized description of the action.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XSeekable(XInterface_8f010a43):
    """
    makes it possible to seek to a certain position within a stream.
    
    This interface should be supported, if it is possible to access the data at the new position quickly. You should not support this interface, if you have a continuous stream, for example, a video stream.

    See Also:
        `API XSeekable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XSeekable.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.io.XSeekable']

    def getLength(self) -> int:
        """
        returns the length of the stream.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def getPosition(self) -> int:
        """
        returns the current offset of the stream.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
    def seek(self, location: int) -> None:
        """
        changes the seek pointer to a new location relative to the beginning of the stream.
        
        This method changes the seek pointer so subsequent reads and writes can take place at a different location in the stream object. It is an error to seek before the beginning of the stream or after the end of the stream.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.io.IOException: ``IOException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal


class ContentInfoAttribute(object):
    """
    Const

    These are the possible values for ContentInfo.Attributes.

    See Also:
        `API ContentInfoAttribute <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1ContentInfoAttribute.html>`_
    """
    NONE: Literal[0]
    """
    No extra attributes.
    """
    INSERT_WITH_INPUTSTREAM: Literal[1]
    """
    Supply an input stream with the InsertCommandArgument, when committing the new content by executing the command \"insert\" at it.
    """
    KIND_DOCUMENT: Literal[2]
    """
    The new content is of kind document.
    
    It's value for the property \"IsDocument\" will be true.
    """
    KIND_FOLDER: Literal[4]
    """
    The new content is of kind folder.
    
    It's value for the property \"IsFolder\" will be true.
    """
    KIND_LINK: Literal[8]
    """
    The new content is of kind link.
    
    It will support the property \"TargetURL\" ( which identifies it as a link ).
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.form.control
from ...awt.uno_control_edit import UnoControlEdit as UnoControlEdit_bc4e0bed
from ..x_bound_control import XBoundControl as XBoundControl_bba00bed
from ..x_change_broadcaster import XChangeBroadcaster as XChangeBroadcaster_fabf0dc4

class TextField(UnoControlEdit_bc4e0bed, XBoundControl_bba00bed, XChangeBroadcaster_fabf0dc4):
    """
    Service Class

    describes a control for entering arbitrary text which can (but not necessarily has to) be bound to a database field.
    
    The model of the control has to support the com.sun.star.form.component.TextField service.
    
    In addition, this control can be used in HTML forms. It triggers the com.sun.star.form.XSubmit.submit() method of the form it belongs to if the enter is pressed while it has the focus.

    See Also:
        `API TextField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1control_1_1TextField.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.animations
from typing_extensions import Literal
import typing
from .x_animation_node import XAnimationNode as XAnimationNode_1cf10eb9
if typing.TYPE_CHECKING:
    from .time_filter_pair import TimeFilterPair as TimeFilterPair_1d250ebc

class XAnimate(XAnimationNode_1cf10eb9):
    """
    Interface for generic animation.

    See Also:
        `API XAnimate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimate.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.animations.XAnimate']

    @property
    def KeyTimes(self) -> 'typing.Tuple[float, ...]':
        """
        """

    @property
    def TimeFilter(self) -> 'typing.Tuple[TimeFilterPair_1d250ebc, ...]':
        """
        todo: timeFilter=\"0,0; 0.14,0.36; 0.43,0.73; 0.71,0.91; 1.0,1.0\" ?
        """

    @property
    def Values(self) -> 'typing.Tuple[object, ...]':
        """
        A sequence of one or more values, each of which must be a legal value for the specified attribute.
        """

    @property
    def Accumulate(self) -> bool:
        """
        Controls whether or not the animation is cumulative.
        """

    @property
    def Additive(self) -> int:
        """
        Controls whether or not the animation is additive.
        """

    @property
    def AttributeName(self) -> str:
        """
        Specifies the target attribute.
        """

    @property
    def By(self) -> object:
        """
        Specifies a relative offset value for the animation.
        
        Must be a legal value of a domain for which addition to the attributeType domain is defined and which yields a value in the attributeType domain. Ignored if the values attribute is specified. Ignored if the Values attribute is specified.
        """

    @property
    def CalcMode(self) -> int:
        """
        Specifies the interpolation mode for the animation.
        
        If the target attribute does not support linear interpolation (e.g. for strings), or if the values attribute has only one value, the CalcMode attribute is ignored and discrete interpolation is used.
        """

    @property
    def Formula(self) -> str:
        """
        if this string is set, its contents will be parsed as a formula.
        
        All values are used as a parameter for this formula and the computed result will be used.
        """

    @property
    def From(self) -> object:
        """
        Specifies the starting value of the animation.
        
        Must be a legal value for the specified attribute. Ignored if the Values attribute is specified.
        """

    @property
    def SubItem(self) -> int:
        """
        This attribute specifies an optional subitem from the target element that should be animated.
        
        A value of zero should always be the default and animate the complete target.
        See documentation of used animation engine for supported subitems.
        """

    @property
    def Target(self) -> object:
        """
        This attribute specifies the target element to be animated.
        
        See documentation of used animation engine for supported targets.
        """

    @property
    def To(self) -> object:
        """
        Specifies the ending value of the animation.
        
        Must be a legal value for the specified attribute. Ignored if the Values attribute is specified.
        """

    @property
    def ValueType(self) -> int:
        """
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.ucb
from typing_extensions import Literal
"""
Const

The notational conventions used to denote file system paths on different file systems or operating systems.

See Also:
    `API FileSystemNotation <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb_1_1FileSystemNotation.html>`_
"""
UNKNOWN_NOTATION: Literal[0]
"""
No information regarding any conventions is available.
"""
UNIX_NOTATION: Literal[1]
"""
The conventions of Unix like file systems (e.g., /dir1/dir2/file).
"""
DOS_NOTATION: Literal[2]
"""
The conventions of DOS like file systems (e.g., a:\\dir1\\dir2\\file or UNC notation like \\\\host\\dir1\\dir2\\file).
"""
MAC_NOTATION: Literal[3]
"""
The conventions of Mac like file systems (e.g., volume:dir1:dir2:file).
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
"""
Const

Category of number format code.

See Also:
    `API KNumberFormatUsage <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1KNumberFormatUsage.html>`_
"""
DATE: Literal[1]
"""
Date format, for example, \"YYYY-MM-DD\".
"""
TIME: Literal[2]
"""
Time format, for example, \"HH:MM:SS\".
"""
DATE_TIME: Literal[3]
"""
Mixed date/time format, for example, \"YYYY-MM-DD HH:MM:SS\".
"""
FIXED_NUMBER: Literal[4]
"""
Numeric format, for example, \"#,##0.00\".
"""
FRACTION_NUMBER: Literal[5]
"""
Fractional format, for example, \"# ??/??\".
"""
PERCENT_NUMBER: Literal[6]
"""
Percent format, for example, \"0.00%\".
"""
SCIENTIFIC_NUMBER: Literal[7]
"""
Scientific format, for example, \"0.00E+00\".
"""
CURRENCY: Literal[8]
"""
Currency format, for example, \"#,##0.00 [$EUR]\".
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from ..awt.point import Point as Point_5fb2085e


class GluePoint(object):
    """
    Struct Class

    A GluePoint could be attached to a shape or to a page.
    
    If a GluePoint is attached to a shape, it is moved when the shape moves. The ends of connectors can be attached to GluePoint.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API GluePoint <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1GluePoint.html>`_
    """
    typeName: Literal['com.sun.star.drawing.GluePoint']

    def __init__(self, Position: typing.Optional[Point_5fb2085e] = ..., EscapeDirection: typing.Optional[int] = ..., PositionAbsolute: typing.Optional[bool] = ..., Alignment: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Position (Point, optional): Position value.
            EscapeDirection (int, optional): EscapeDirection value.
            PositionAbsolute (bool, optional): PositionAbsolute value.
            Alignment (int, optional): Alignment value.
        """


    @property
    def Position(self) -> Point_5fb2085e:
        """
        This is the position of this GluePoint.
        """


    @property
    def EscapeDirection(self) -> int:
        """
        This is the direction in which the connector line leaves the GluePoint.
        """


    @property
    def PositionAbsolute(self) -> bool:
        """
        If this is TRUE, then the position of this GluePoint is absolute on a page and is not relative to a shape.
        """


    @property
    def Alignment(self) -> int:
        """
        The alignment of a GluePoint defines how the position of the point is affected by resizing the parent Shape.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing
from .dash_style import DashStyle as DashStyle_b10d0b85


class LineDash(object):
    """
    Struct Class

    A LineDash defines a non-continuous line.

    See Also:
        `API LineDash <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1LineDash.html>`_
    """
    typeName: Literal['com.sun.star.drawing.LineDash']

    def __init__(self, Style: typing.Optional[DashStyle_b10d0b85] = ..., Dots: typing.Optional[int] = ..., DotLen: typing.Optional[int] = ..., Dashes: typing.Optional[int] = ..., DashLen: typing.Optional[int] = ..., Distance: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Style (DashStyle, optional): Style value.
            Dots (int, optional): Dots value.
            DotLen (int, optional): DotLen value.
            Dashes (int, optional): Dashes value.
            DashLen (int, optional): DashLen value.
            Distance (int, optional): Distance value.
        """


    @property
    def Style(self) -> DashStyle_b10d0b85:
        """
        This sets the style of this LineDash.
        """


    @property
    def Dots(self) -> int:
        """
        This is the number of dots in this LineDash.
        """


    @property
    def DotLen(self) -> int:
        """
        This is the length of a dot.
        """


    @property
    def Dashes(self) -> int:
        """
        This is the number of dashes.
        """


    @property
    def DashLen(self) -> int:
        """
        This is the length of a single dash.
        """


    @property
    def Distance(self) -> int:
        """
        This is the distance between the dots.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.configuration
from .set_access import SetAccess as SetAccess_1ae0dfe
from .simple_set_update import SimpleSetUpdate as SimpleSetUpdate_5f4d1079

class SetUpdate(SetAccess_1ae0dfe, SimpleSetUpdate_5f4d1079):
    """
    Service Class

    provides write access to a dynamic homogeneous set of values or nested trees within a hierarchy.
    
    Allows adding and removing elements. Helps creates new elements to be added.
    
    This service extends SetAccess to support modifying the container.
    
    Any child and descendant objects support modifying access as well, unless they represent a read-only tree element (as indicated by com.sun.star.beans.PropertyAttribute.READONLY).

    See Also:
        `API SetUpdate <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1SetUpdate.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCurrencyField(XInterface_8f010a43):
    """
    gives access to the value and formatting of a currency field.

    See Also:
        `API XCurrencyField <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XCurrencyField.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XCurrencyField']

    def getDecimalDigits(self) -> int:
        """
        returns the currently set number of decimals.
        """
    def getFirst(self) -> float:
        """
        returns the currently set first value which is set on POS1 key.
        """
    def getLast(self) -> float:
        """
        returns the currently set last value which is set on END key.
        """
    def getMax(self) -> float:
        """
        returns the currently set maximum value that can be entered by the user.
        """
    def getMin(self) -> float:
        """
        returns the currently set minimum value that can be entered by the user.
        """
    def getSpinSize(self) -> float:
        """
        returns the currently set increment value for the spin button.
        """
    def getValue(self) -> float:
        """
        returns the value which is currently displayed in the currency field.
        """
    def isStrictFormat(self) -> bool:
        """
        returns whether the format is currently checked during user input.
        """
    def setDecimalDigits(self, nDigits: int) -> None:
        """
        sets the number of decimals.
        """
    def setFirst(self, Value: float) -> None:
        """
        sets the first value to be set on POS1 key.
        """
    def setLast(self, Value: float) -> None:
        """
        sets the last value to be set on END key.
        """
    def setMax(self, Value: float) -> None:
        """
        sets the maximum value that can be entered by the user.
        """
    def setMin(self, Value: float) -> None:
        """
        sets the minimum value that can be entered by the user.
        """
    def setSpinSize(self, Value: float) -> None:
        """
        sets the increment value for the spin button.
        """
    def setStrictFormat(self, bStrict: bool) -> None:
        """
        determines if the format is checked during user input.
        """
    def setValue(self, Value: float) -> None:
        """
        sets the value which is displayed in the currency field.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_item_list_listener import XItemListListener as XItemListListener_e1020d1d

class XItemList(ABC):
    """
    provides convenient access to the list of items in a list box

    See Also:
        `API XItemList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XItemList.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XItemList']

    def addItemListListener(self, Listener: 'XItemListListener_e1020d1d') -> None:
        """
        registers a listener which is notified about changes in the item list.
        """
    def getAllItems(self) -> 'typing.Tuple[typing.Tuple[str, str], ...]':
        """
        retrieves the texts and images of all items in the list
        """
    def getItemData(self, Position: int) -> object:
        """
        retrieves the implementation dependent value associated with the given list item.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getItemImage(self, Position: int) -> str:
        """
        retrieves the URL of the image of an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getItemText(self, Position: int) -> str:
        """
        retrieves the text of an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def getItemTextAndImage(self, Position: int) -> 'typing.Tuple[str, str]':
        """
        retrieves both the text and the image URL of an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def insertItem(self, Position: int, ItemText: str, ItemImageURL: str) -> None:
        """
        inserts a new item into the list

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def insertItemImage(self, Position: int, ItemImageURL: str) -> None:
        """
        inserts an item which has only an image, but no text

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def insertItemText(self, Position: int, ItemText: str) -> None:
        """
        inserts an item which has only a text, but no image

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def removeAllItems(self) -> None:
        """
        removes all items from the list
        """
    def removeItem(self, Position: int) -> None:
        """
        removes an item from the list

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def removeItemListListener(self, Listener: 'XItemListListener_e1020d1d') -> None:
        """
        revokes a listener which is notified about changes in the item list.
        """
    def setItemData(self, Position: int, ItemData: object) -> None:
        """
        associates an implementation dependent value with the given list item.
        
        You can use this to store data for an item which does not interfere with the displayed text and image, but can be used by the client of the list box for an arbitrary purpose.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setItemImage(self, Position: int, ItemImageURL: str) -> None:
        """
        sets a new image for an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setItemText(self, Position: int, ItemText: str) -> None:
        """
        sets a new text for an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    def setItemTextAndImage(self, Position: int, ItemText: str, ItemImageURL: str) -> None:
        """
        sets both a new position and text for an existing item

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
    @property
    def ItemCount(self) -> int:
        """
        is the number of items in the list
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.style
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from .graphic_location import GraphicLocation as GraphicLocation_e3ef0d30
    from .page_style_layout import PageStyleLayout as PageStyleLayout_e4070d45
    from ..table.border_line import BorderLine as BorderLine_a3f80af6
    from ..table.shadow_format import ShadowFormat as ShadowFormat_bb840bdf
    from ..text.x_text import XText as XText_690408ca
    from ..text.x_text_columns import XTextColumns as XTextColumns_b17f0bab
    from ..util.color import Color as Color_68e908c5

class PageProperties(ABC):
    """
    Service Class

    describes the style of pages.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API PageProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1PageProperties.html>`_
    """
    @property
    def BackColor(self) -> 'Color_68e908c5':
        """
        contains the background color of the page.
        """
    @property
    def BackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic of the background.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def BackGraphicFilter(self) -> str:
        """
        contains the filter name of the background graphic.
        """
    @property
    def BackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        determines the location of the background graphic.
        """
    @property
    def BackGraphicURL(self) -> str:
        """
        contains the URL of the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
    @property
    def BackTransparent(self) -> bool:
        """
        determines if the background color is transparent.
        
        If this property is set to TRUE, PageStyle.BackColor will not be used.
        """
    @property
    def BackgroundFullSize(self) -> bool:
        """
        does the background cover the full page or only inside the margins?
        
        **since**
        
            LibreOffice 7.2
        """
    @property
    def BorderDistance(self) -> int:
        """
        determines the distance of all borders of the page.
        """
    @property
    def BottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the bottom border line of the page.
        """
    @property
    def BottomBorderDistance(self) -> int:
        """
        determines the bottom border distance of the page.
        """
    @property
    def BottomMargin(self) -> int:
        """
        determines the bottom margin of the page.
        """
    @property
    def FirstIsShared(self) -> bool:
        """
        determines if the header/footer content on the first page and remaining pages is the same.
        
        **since**
        
            LibreOffice 4.0
        """
    @property
    def FooterBackColor(self) -> 'Color_68e908c5':
        """
        contains the color of the background of the footer.
        """
    @property
    def FooterBackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic of the background of the footer.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def FooterBackGraphicFilter(self) -> str:
        """
        contains the filter name of the background graphic in the footer.
        """
    @property
    def FooterBackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        determines the location of the background graphic in the footer.
        """
    @property
    def FooterBackGraphicURL(self) -> str:
        """
        contains the URL of the background graphic in the footer.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the FooterBackGraphic property.
        """
    @property
    def FooterBackTransparent(self) -> bool:
        """
        determines if the background of the footer is transparent.
        """
    @property
    def FooterBodyDistance(self) -> int:
        """
        determines the distance between the footer and the body text area.
        """
    @property
    def FooterBorderDistance(self) -> int:
        """
        contains the distance of all borders of the footer.
        """
    @property
    def FooterBottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the style of the bottom border line of the footer.
        """
    @property
    def FooterBottomBorderDistance(self) -> int:
        """
        contains the bottom border distance of the footer.
        """
    @property
    def FooterDynamicSpacing(self) -> bool:
        """
        determines whether to use dynamic spacing in footer or not.
        """
    @property
    def FooterHeight(self) -> int:
        """
        determines the height of the footer.
        """
    @property
    def FooterIsDynamicHeight(self) -> bool:
        """
        determines if the height of the footer depends on the content.
        """
    @property
    def FooterIsOn(self) -> bool:
        """
        determines if a footer is used on the page.
        """
    @property
    def FooterIsShared(self) -> bool:
        """
        determines if the footer content on left and right pages is the same.
        """
    @property
    def FooterLeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the style of the left border line of the footer.
        """
    @property
    def FooterLeftBorderDistance(self) -> int:
        """
        contains the left border distance of the footer.
        """
    @property
    def FooterLeftMargin(self) -> int:
        """
        determines the left margin of the footer.
        """
    @property
    def FooterRightBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the style of the right border line of the footer.
        """
    @property
    def FooterRightBorderDistance(self) -> int:
        """
        contains the right border distance of the footer.
        """
    @property
    def FooterRightMargin(self) -> int:
        """
        determines the right margin of the footer.
        """
    @property
    def FooterShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        determines the shadow of the footer.
        """
    @property
    def FooterText(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the footer.
        """
    @property
    def FooterTextLeft(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the footer of a left page.
        """
    @property
    def FooterTextRight(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the footer of a right page.
        """
    @property
    def FooterTopBorder(self) -> 'BorderLine_a3f80af6':
        """
        contains the style of the top border line of the footer.
        """
    @property
    def FooterTopBorderDistance(self) -> int:
        """
        contains the top border distance of the footer.
        """
    @property
    def FootnoteHeight(self) -> int:
        """
        contains the maximum height of the footnote area.
        
        If set to zero then the height of the current page is used as limit.
        """
    @property
    def FootnoteLineAdjust(self) -> int:
        """
        contains the adjustment of the separator line between the text and the footnote area.
        
        com.sun.star.text.HorizontalAdjusts.
        """
    @property
    def FootnoteLineColor(self) -> 'Color_68e908c5':
        """
        contains the color of the separator line between the text and the footnote area.
        """
    @property
    def FootnoteLineDistance(self) -> int:
        """
        contains the distance between the footnote area and the separator line between the text and the footnote area.
        """
    @property
    def FootnoteLineRelativeWidth(self) -> int:
        """
        contains the relative width of the separator line between the text and the footnote area.
        """
    @property
    def FootnoteLineStyle(self) -> int:
        """
        contains the style of the separator line between the text and the footnote area.
        """
    @property
    def FootnoteLineTextDistance(self) -> int:
        """
        contains the distance between the text and the separator line between the text and the footnote area.
        """
    @property
    def FootnoteLineWeight(self) -> int:
        """
        contains the weight of the separator line between the text and the footnote area.
        """
    @property
    def GridBaseHeight(self) -> int:
        """
        contains the height of the base text line inside the text grid
        """
    @property
    def GridColor(self) -> 'Color_68e908c5':
        """
        contains the display color of the text grid
        """
    @property
    def GridDisplay(self) -> bool:
        """
        determines whether the text grid lines are visible or not
        """
    @property
    def GridLines(self) -> int:
        """
        contains the number of lines in the text grid
        """
    @property
    def GridMode(self) -> int:
        """
        contains the mode of the text grid (none, lines, ...), as represented by com.sun.star.text.TextGridMode constants
        """
    @property
    def GridPrint(self) -> bool:
        """
        determines whether the text grid lines are printed
        """
    @property
    def GridRubyBelow(self) -> bool:
        """
        determines whether the text grid's ruby line is located below or above the base line
        """
    @property
    def GridRubyHeight(self) -> int:
        """
        contains the height of the ruby text line inside the text grid
        """
    @property
    def GutterMargin(self) -> int:
        """
        determines the gutter margin of the page.
        
        **since**
        
            LibreOffice 7.2
        """
    @property
    def HeaderBackColor(self) -> 'Color_68e908c5':
        """
        contains the color of the background of the header.
        """
    @property
    def HeaderBackGraphic(self) -> 'XGraphic_a4da0afc':
        """
        contains the graphic of the background of the header.
        
        **since**
        
            LibreOffice 6.1
        """
    @property
    def HeaderBackGraphicFilter(self) -> str:
        """
        contains the filter name of the background graphic of the header.
        """
    @property
    def HeaderBackGraphicLocation(self) -> 'GraphicLocation_e3ef0d30':
        """
        determines the location of the background graphic of the header.
        """
    @property
    def HeaderBackGraphicURL(self) -> str:
        """
        contains the URL of the background graphic of the header.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the HeaderBackGraphic property.
        """
    @property
    def HeaderBackTransparent(self) -> bool:
        """
        determines if the background color of the header is transparent.
        
        If this property is set to TRUE, PageStyle.HeaderBackColor will not be used.
        """
    @property
    def HeaderBodyDistance(self) -> int:
        """
        determines the distance between the header and the body text area.
        """
    @property
    def HeaderBorderDistance(self) -> int:
        """
        determines the distance of all borders of the header.
        """
    @property
    def HeaderBottomBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the bottom border line of the header.
        """
    @property
    def HeaderBottomBorderDistance(self) -> int:
        """
        determines the bottom border distance of the header.
        """
    @property
    def HeaderDynamicSpacing(self) -> bool:
        """
        determines whether to use dynamic spacing in header or not.
        """
    @property
    def HeaderHeight(self) -> int:
        """
        contains the height of the header.
        """
    @property
    def HeaderIsDynamicHeight(self) -> bool:
        """
        determines if the height of the header depends on the content.
        """
    @property
    def HeaderIsOn(self) -> bool:
        """
        determines if a header is used on the page.
        """
    @property
    def HeaderIsShared(self) -> bool:
        """
        determines if the header content on left and right pages is the same.
        """
    @property
    def HeaderLeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the left border line of the header.
        """
    @property
    def HeaderLeftBorderDistance(self) -> int:
        """
        determines the left border distance of the header.
        """
    @property
    def HeaderLeftMargin(self) -> int:
        """
        contains the left margin of the header.
        """
    @property
    def HeaderRightBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the right border line of the header.
        """
    @property
    def HeaderRightBorderDistance(self) -> int:
        """
        determines the right border distance of the header.
        """
    @property
    def HeaderRightMargin(self) -> int:
        """
        contains the right margin of the header.
        """
    @property
    def HeaderShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        determines the shadow of the header.
        """
    @property
    def HeaderText(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the header.
        """
    @property
    def HeaderTextLeft(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the header of left pages.
        """
    @property
    def HeaderTextRight(self) -> 'XText_690408ca':
        """
        contains the interface to the text of the header of right pages.
        """
    @property
    def HeaderTopBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the top border line of the header.
        """
    @property
    def HeaderTopBorderDistance(self) -> int:
        """
        determines the top border distance of the header.
        """
    @property
    def Height(self) -> int:
        """
        contains the height of the page.
        """
    @property
    def IsLandscape(self) -> bool:
        """
        determines if the page format is landscape.
        """
    @property
    def LeftBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the left border line of the page.
        """
    @property
    def LeftBorderDistance(self) -> int:
        """
        determines the left border distance of the page.
        """
    @property
    def LeftMargin(self) -> int:
        """
        determines the left margin of the page.
        """
    @property
    def NumberingType(self) -> int:
        """
        determines the default numbering type for this page.
        """
    @property
    def PageStyleLayout(self) -> 'PageStyleLayout_e4070d45':
        """
        determines the layout of the page.
        """
    @property
    def PrinterPaperTray(self) -> str:
        """
        contains the name of a paper tray of the selected printer.
        """
    @property
    def RegisterModeActive(self) -> bool:
        """
        determines if the register mode is active on that page.
        """
    @property
    def RegisterParagraphStyle(self) -> str:
        """
        contains the name of the paragraph style that is used as reference of the register mode.
        """
    @property
    def RightBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the right border line of the page.
        """
    @property
    def RightBorderDistance(self) -> int:
        """
        determines the right border distance of the page.
        """
    @property
    def RightMargin(self) -> int:
        """
        determines the right margin of the page.
        """
    @property
    def RtlGutter(self) -> bool:
        """
        specifies that the page gutter shall be placed on the right side of the page.
        
        **since**
        
            LibreOffice 7.2
        """
    @property
    def ShadowFormat(self) -> 'ShadowFormat_bb840bdf':
        """
        determines the shadow of the page.
        """
    @property
    def Size(self) -> 'Size_576707ef':
        """
        contains the paper size of the page.
        """
    @property
    def TextColumns(self) -> 'XTextColumns_b17f0bab':
        """
        contains the column settings of the page.
        """
    @property
    def TopBorder(self) -> 'BorderLine_a3f80af6':
        """
        determines the style of the top border line of the page.
        """
    @property
    def TopBorderDistance(self) -> int:
        """
        determines the top border distance of the page.
        """
    @property
    def TopMargin(self) -> int:
        """
        determines the top margin of the page.
        """
    @property
    def UserDefinedAttributes(self) -> 'XNameContainer_cb90e47':
        """
        contains user defined attributes.
        
        This com.sun.star.container.XNameContainer supports the service com.sun.star.xml.AttributeContainer.
        """
    @property
    def Width(self) -> int:
        """
        contains the width of the page.
        """
    @property
    def WritingMode(self) -> int:
        """
        contains the writing direction, as represented by the com.sun.star.text.WritingMode2 constants
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal


class MeasureUnit(object):
    """
    Const

    These constants are used to specify a measure.
    
    A component using these constants may not support all units.

    See Also:
        `API MeasureUnit <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1MeasureUnit.html>`_
    """
    MM_100TH: Literal[0]
    """
    all measures for this component are in 100th millimeter
    """
    MM_10TH: Literal[1]
    """
    all measures for this component are in 10th millimeter
    """
    MM: Literal[2]
    """
    all measures for this component are in millimeter
    """
    CM: Literal[3]
    """
    all measures for this component are in centimeters
    """
    INCH_1000TH: Literal[4]
    """
    all measures for this component are in 1000th inch
    """
    INCH_100TH: Literal[5]
    """
    all measures for this component are in 100th inch
    """
    INCH_10TH: Literal[6]
    """
    all measures for this component are in 10th inch
    """
    INCH: Literal[7]
    """
    all measures for this component are in inch
    """
    POINT: Literal[8]
    """
    all measures for this component are in points
    """
    TWIP: Literal[9]
    """
    all measures for this component are in twips
    """
    M: Literal[10]
    """
    all measures for this component are in meters
    """
    KM: Literal[11]
    """
    all measures for this component are in kilometers
    """
    PICA: Literal[12]
    """
    all measures for this component are in pica
    """
    FOOT: Literal[13]
    """
    all measures for this component are in foot
    """
    MILE: Literal[14]
    """
    all measures for this component are in miles
    """
    PERCENT: Literal[15]
    """
    all measures for this component are in percentage
    """
    PIXEL: Literal[16]
    """
    all measures for this component are in pixel
    """
    APPFONT: Literal[17]
    """
    all measures for this component are in APPFONT
    """
    SYSFONT: Literal[18]
    """
    all measures for this component are in SYSFONT
    """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.text
from .text_content import TextContent as TextContent_a6810b4d

class BaseIndexMark(TextContent_a6810b4d):
    """
    Service Class

    is a TextRange which is explicitly marked as an index entry.
    
    This is the base service of index marks for DocumentIndex, ContentIndex, and UserIndex.

    See Also:
        `API BaseIndexMark <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1BaseIndexMark.html>`_
    """
    @property
    def AlternativeText(self) -> str:
        """
        the string that will be inserted into the corresponding index.
        
        If AlternativeText is empty then the string that is marked by the TextRange is inserted into the index.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.3
from typing_extensions import Literal
import typing


class CellRangeAddress(object):
    """
    Struct Class

    contains a cell range address within a spreadsheet document.

    See Also:
        `API CellRangeAddress <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1CellRangeAddress.html>`_
    """
    typeName: Literal['com.sun.star.table.CellRangeAddress']

    def __init__(self, Sheet: typing.Optional[int] = ..., StartColumn: typing.Optional[int] = ..., StartRow: typing.Optional[int] = ..., EndColumn: typing.Optional[int] = ..., EndRow: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Sheet (int, optional): Sheet value.
            StartColumn (int, optional): StartColumn value.
            StartRow (int, optional): StartRow value.
            EndColumn (int, optional): EndColumn value.
            EndRow (int, optional): EndRow value.
        """


    @property
    def Sheet(self) -> int:
        """
        is the index of the sheet that contains the cell range.
        """


    @property
    def StartColumn(self) -> int:
        """
        is the index of the column of the left edge of the range.
        """


    @property
    def StartRow(self) -> int:
        """
        is the index of the row of the top edge of the range.
        """


    @property
    def EndColumn(self) -> int:
        """
        is the index of the column of the right edge of the range.
        """


    @property
    def EndRow(self) -> int:
        """
        is the index of the row of the bottom edge of the range.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.frame
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_frame import XFrame as XFrame_7a570956
    from ..util.url import URL as URL_57ad07b9

class XDispatchRecorder(XInterface_8f010a43):
    """
    provides recording functionality of dispatches
    
    With such recorder it will be possible to record requests of type XDispatch by using additional interface XRecordableDispatch. The result of that will be a a script which can be used to start the dispatch at later time again. Such recorder objects are available on a XDispatchRecorderSupplier which is provided by the Frame service.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XDispatchRecorder <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDispatchRecorder.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.frame.XDispatchRecorder']

    def endRecording(self) -> None:
        """
        stops the recording process
        
        Must be called in pairs with XDispatchRecorder.startRecording().
        """
    def getRecordedMacro(self) -> str:
        """
        returns the recorded source code
        
        This method must be used before endRecording() is called! Otherwise the macro will be released.
        """
    def recordDispatch(self, URL: 'URL_57ad07b9', Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        records a single dispatch call identified by its command URL
        """
    def recordDispatchAsComment(self, URL: 'URL_57ad07b9', Arguments: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        records a single dispatch call identified by its command URL, but comments it out
        
        This way calls that failed on execution can be documented.
        """
    def startRecording(self, Frame: 'XFrame_7a570956') -> None:
        """
        initializes the recorder by passing the frame for which all macro statements shall be recorded
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.util
from typing_extensions import Literal
"""
Const

contains constants that are used to specify the type of a number format.

See Also:
    `API NumberFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1util_1_1NumberFormat.html>`_
"""
ALL: Literal[0]
"""
selects all number formats.
"""
DEFINED: Literal[1]
"""
selects only user-defined number formats.
"""
DATE: Literal[2]
"""
selects date formats.
"""
TIME: Literal[4]
"""
selects time formats.
"""
CURRENCY: Literal[8]
"""
selects currency formats.
"""
NUMBER: Literal[16]
"""
selects decimal number formats.
"""
SCIENTIFIC: Literal[32]
"""
selects scientific number formats.
"""
FRACTION: Literal[64]
"""
selects number formats for fractions.
"""
PERCENT: Literal[128]
"""
selects percentage number formats.
"""
TEXT: Literal[256]
"""
selects text number formats.
"""
DATETIME: Literal[6]
"""
selects number formats which contain date and time.
"""
LOGICAL: Literal[1024]
"""
selects boolean number formats.
"""
UNDEFINED: Literal[2048]
"""
is used as a return value if no format exists.
"""
EMPTY: Literal[4096]
DURATION: Literal[8196]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.deployment
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from .x_package import XPackage as XPackage_cb1f0c4d
    from .x_package_type_info import XPackageTypeInfo as XPackageTypeInfo_3bc70f7b
    from ..ucb.x_command_environment import XCommandEnvironment as XCommandEnvironment_fb330dee

class XPackageRegistry(ABC):
    """
    Interface to bind a UNO package.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPackageRegistry <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XPackageRegistry.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.deployment.XPackageRegistry']

    def bindPackage(self, url: str, mediaType: str, removed: bool, identifier: str, xCmdEnv: 'XCommandEnvironment_fb330dee') -> 'XPackage_cb1f0c4d':
        """
        binds a package URL to a XPackage handle.
        
        The returned UNO package handle ought to late-initialize itself, thus the process of binding must not be an expensive operation, because it is not abortable.
        
        Calling the function several time with the same parameters must result in returning the same object.
        
        The file or folder at the location where url points to may not exist or it was replaced. This can happen, for example, when a bundled extension was removed by the setup and a user later starts OOo. Then the user data may still contain all registration data of that extension, but the actual extension files do not exist anymore. The registration data must then be cleaned of all the remains of that extension. To do that one creates an XPackage object on behalf of that extension and calls XPackage.revokePackage(). The parameter removed indicates this case. The returned object may not rely on the file or folder to which refers url. Instead it must use previously saved data to successfully carry out the revocation of this object (XPackage.revokePackage()).
        
        The implementation must ensure that there is only one instance of XPackage for the same url at any time. Therefore calling bindPackage() again with the same url but different mediaType (the exception is, if previously an empty string was provided to cause the determination of the media type) or removed parameters will cause an exception. A com.sun.star.lang.IllegalArgumentException will be thrown in case of a different mediaType parameter and a InvalidRemovedParameterException is thrown if the removed parameter is different.
        
        The identifier parameter must be provided when removed = true. If not, then an com.sun.star.lang.IllegalArgumentException will be thrown.

        Raises:
            DeploymentException: ``DeploymentException``
            InvalidRemovedParameterException: ``InvalidRemovedParameterException``
            com.sun.star.ucb.CommandFailedException: ``CommandFailedException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def getSupportedPackageTypes(self) -> 'typing.Tuple[XPackageTypeInfo_3bc70f7b, ...]':
        """
        gets the supported XPackageTypeInfos.
        """
    def packageRemoved(self, url: str, mediaType: str) -> None:
        """

        Raises:
            DeploymentException: ``DeploymentException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.smarttags
from typing_extensions import Literal
import typing
from ..lang.x_initialization import XInitialization as XInitialization_d46c0cca
if typing.TYPE_CHECKING:
    from ..frame.x_controller import XController as XController_b00e0b8f
    from .smart_tag_recognizer_mode import SmartTagRecognizerMode as SmartTagRecognizerMode_9179119e
    from ..text.x_text_markup import XTextMarkup as XTextMarkup_a5d60b3a
    from ..text.x_text_range import XTextRange as XTextRange_9a910ab7

class XRangeBasedSmartTagRecognizer(XInitialization_d46c0cca):
    """
    provides access to a range based smart tag recognizer.

    See Also:
        `API XRangeBasedSmartTagRecognizer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1smarttags_1_1XRangeBasedSmartTagRecognizer.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.smarttags.XRangeBasedSmartTagRecognizer']

    def recognizeTextRange(self, xRange: 'XTextRange_9a910ab7', eDataType: 'SmartTagRecognizerMode_9179119e', xTextMarkup: 'XTextMarkup_a5d60b3a', aApplicationName: str, xController: 'XController_b00e0b8f') -> None:
        """
        recognizes smart tags.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from typing_extensions import Literal
"""
Const

These values are used to specify the kind of strikeout.

They may be expanded in future versions.

See Also:
    `API FontStrikeout <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1awt_1_1FontStrikeout.html>`_
"""
NONE: Literal[0]
"""
specifies not to strike out the characters.
"""
SINGLE: Literal[1]
"""
specifies to strike out the characters with a single line.
"""
DOUBLE: Literal[2]
"""
specifies to strike out the characters with a double line.
"""
DONTKNOW: Literal[3]
"""
The strikeout mode is not specified.
"""
BOLD: Literal[4]
"""
specifies to strike out the characters with a bold line.
"""
SLASH: Literal[5]
"""
specifies to strike out the characters with slashes.
"""
X: Literal[6]
"""
specifies to strike out the characters with X's.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.i18n
from typing_extensions import Literal
import typing
from .x_locale_data2 import XLocaleData2 as XLocaleData2_a7ac0a9c
if typing.TYPE_CHECKING:
    from .calendar2 import Calendar2 as Calendar2_88c10994
    from ..lang.locale import Locale as Locale_70d308fa

class XLocaleData3(XLocaleData2_a7ac0a9c):
    """
    Access locale specific data.
    
    Derived from com.sun.star.i18n.XLocaleData2 this provides an additional method to return a sequence of all com.sun.star.i18n.Calendar2 elements available for that locale.
    
    **since**
    
        LibreOffice 3.5

    See Also:
        `API XLocaleData3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XLocaleData3.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.i18n.XLocaleData3']

    def getAllCalendars2(self, aLocale: 'Locale_70d308fa') -> 'typing.Tuple[Calendar2_88c10994, ...]':
        """
        returns all LC_CALENDAR calendars for a locale.
        """

